<?php

namespace Drupal\samenwerkende_catalogi\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the configuration export form.
 */
class SamenwerkendeCatalogiSettingsForm extends ConfigFormBase {

  /**
   * @var \Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiFormService
   */
  protected $samenwerkendeCatalogiFormService;

  /**
   * SamenwerkendeCatalogiSettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   * @param \Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiFormService $samenwerkende_catalogi_form
   */
  public function __construct(ConfigFactoryInterface $config_factory, SamenwerkendeCatalogiFormService $samenwerkende_catalogi_form) {
    $this->samenwerkendeCatalogiFormService = $samenwerkende_catalogi_form;
    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('samenwerkende_catalogi_form')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'samenwerkende_catalogi_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['samenwerkende_catalogi.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('samenwerkende_catalogi.settings');

    $form += $this->samenwerkendeCatalogiFormService->build('node');

    $form['status']['#default_value'] = $settings->get('status');

    $data = $settings->get('data');
    $form['data']['title']['#default_value'] = isset($data['title']) ? $data['title'] : '';
    $form['data']['authority']['#default_value'] = isset($data['authority']) ? $data['authority'] : '';
    $form['data']['spatial']['#default_value'] = isset($data['spatial']) ? $data['spatial'] : '';
    $form['data']['audience']['#default_value'] = isset($data['audience']) ? $data['audience'] : [];
    $form['data']['subject']['#default_value'] = isset($data['subject']) ? $data['subject'] : '';
    $form['data']['abstract']['#default_value'] = isset($data['abstract']) ? $data['abstract'] : '';
    $form['data']['onlineAanvragen']['#default_value'] = isset($data['onlineAanvragen']) ? $data['onlineAanvragen'] : [];
    $form['data']['aanvraagURL']['#default_value'] = isset($data['onlineAanvragen']) ? $data['onlineAanvragen'] : '';
    $form['data']['uniformeProductnaam']['#default_value'] = isset($data['uniformeProductnaam']) ? $data['uniformeProductnaam'] : '';
    $form['data']['gerelateerdProduct']['#default_value'] = isset($data['gerelateerdProduct']) ? $data['gerelateerdProduct'] : [];
    $form['data']['productHTML']['#default_value'] = isset($data['productHTML']) ? $data['productHTML'] : [];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $settings = $this->config('samenwerkende_catalogi.settings');

    $form_state->cleanValues();
    $values = $form_state->getValues();
    foreach ($values as $id => $value) {
      $settings->set($id, $value);
    }
    $settings->save();
    parent::submitForm($form, $form_state);
  }

}
