<?php

namespace Drupal\samenwerkende_catalogi\Plugin\Field\FieldWidget;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Widget for Samenwerkende Catalogi field.
 *
 * @FieldWidget(
 *   id = "catalogi_widget",
 *   label = @Translation("Advanced Samenwerkende Catalogi form"),
 *   field_types = {
 *     "catalogi"
 *   }
 * )
 */
class CatalogiFieldWidget extends WidgetBase implements ContainerFactoryPluginInterface {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * @var \Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiFormService
   */
  protected $samenwerkendeCatalogiFormService;

  /**
   * {@inheritdoc}
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, ConfigFactoryInterface $config_factory, SamenwerkendeCatalogiFormService $samenwerkende_catalogi_form,  AccountInterface $current_user) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);
    $this->config = $config_factory->get('samenwerkende_catalogi.settings');
    $this->samenwerkendeCatalogiFormService = $samenwerkende_catalogi_form;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('config.factory'),
      $container->get('samenwerkende_catalogi_form'),
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $config = \Drupal::config('samenwerkende_catalogi.settings');

    /** @var \Drupal\samenwerkende_catalogi\Plugin\Field\FieldType\CatalogiFieldItem $item */
    $item = $items[$delta];

    $element += [
      '#type' => 'details',
    ];
    $element += $this->samenwerkendeCatalogiFormService->build($items->getEntity()->getEntityTypeId());

    $status = !is_null($item->status) ? $item->status : $config->get('status');
    $element['#open'] = $status;
    $element['status']['#default_value'] = $status;

    $element['data']['#states'] = [
      'visible' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $config_default = $config->get('data');
    $item_default = unserialize($item->data, ['allowed_classes' => FALSE]);

    $element['data']['title']['#default_value'] = isset($item_default['title']) ?
      $item_default['title'] :
      (isset($config_default['title']) ? $config_default['title'] : '');
    $element['data']['title']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['authority']['#default_value'] = isset($item_default['authority']) ?
      $item_default['authority'] :
      (isset($config_default['authority']) ? $config_default['authority'] : NULL);
    $element['data']['authority']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['spatial']['#default_value'] = isset($item_default['spatial']) ?
      $item_default['spatial'] :
      (isset($config_default['spatial']) ? $config_default['spatial'] : NULL);
    $element['data']['spatial']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['audience']['#default_value'] = isset($item_default['audience']) ?
      $item_default['audience'] :
      (isset($config_default['audience']) ? $config_default['audience'] : []);
    $element['data']['audience']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['subject']['#default_value'] = isset($item_default['subject']) ?
      $item_default['subject'] :
      (isset($config_default['subject']) ? $config_default['subject'] : '');

    $element['data']['abstract']['#default_value'] = isset($item_default['abstract']) ?
      $item_default['abstract'] :
      (isset($config_default['abstract']) ? $config_default['abstract'] : '');
    $element['data']['abstract']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['onlineAanvragen']['#default_value'] = isset($item_default['onlineAanvragen']) ?
      $item_default['onlineAanvragen'] :
      (isset($config_default['onlineAanvragen']) ? $config_default['onlineAanvragen'] : '');
    $element['data']['onlineAanvragen']['#states'] = [
      'required' => [
        ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
      ],
    ];

    $element['data']['aanvraagURL']['#default_value'] = isset($item_default['aanvraagURL']) ?
      $item_default['aanvraagURL'] :
      (isset($config_default['aanvraagURL']) ? $config_default['aanvraagURL'] : '');
    $element['data']['aanvraagURL']['#states'] = [
      'visible' => [
        [':input[name="' . $items->getName() . '[0][data][onlineAanvragen]"]' => ['value' => 'ja']],
        [':input[name="' . $items->getName() . '[0][data][onlineAanvragen]"]' => ['value' => 'digid']],
      ],
      'required' => [
        [
          ':input[name="' . $items->getName() . '[0][data][onlineAanvragen]"]' => ['value' => 'ja'],
          ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
        ],
        [
          ':input[name="' . $items->getName() . '[0][data][onlineAanvragen]"]' => ['value' => 'digid'],
          ':input[name="' . $items->getName() . '[0][status]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $element['data']['uniformeProductnaam']['#default_value'] = isset($item_default['uniformeProductnaam']) ?
      $item_default['uniformeProductnaam'] :
      (isset($config_default['uniformeProductnaam']) ? $config_default['uniformeProductnaam'] : NULL);

    $element['data']['gerelateerdProduct']['#default_value'] = isset($item_default['gerelateerdProduct']) ?
      $item_default['gerelateerdProduct'] :
      (isset($config_default['gerelateerdProduct']) ? $config_default['gerelateerdProduct'] : []);

    $element['data']['onlineAanvragen']['#default_value'] = isset($item_default['onlineAanvragen']) ?
      $item_default['onlineAanvragen'] :
      (isset($config_default['onlineAanvragen']) ? $config_default['onlineAanvragen'] : '');

    $element['data']['productHTML']['#default_value'] = isset($item_default['productHTML']) ?
      $item_default['productHTML'] :
      (isset($config_default['productHTML']) ? $config_default['productHTML'] : '');

    $element['#group'] = 'advanced';
    $element['#access'] = $this->currentUser->hasPermission('edit samenwerkende catalogi content');
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $id => $value) {
      foreach ($value as $key => $group) {
        if (is_array($group)) {
          $values[$id][$key] = serialize($group);
        }
      }
    }

    return $values;
  }

}
