<?php

namespace Drupal\samenwerkende_catalogi\Service;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Class SamenwerkendeCatalogiFormService
 *
 * @package Drupal\samenwerkende_catalogi\Service
 */
class SamenwerkendeCatalogiFormService {

  use StringTranslationTrait;

  /**
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $samenwerkendeCatalogiResource;

  /**
   * SamenwerkendeCatalogiFormService constructor.
   *
   * @param \Drupal\samenwerkende_catalogi\Service\SamenwerkendeCatalogiResourceService $samenwerkende_catalogi_resource
   */
  public function __construct(SamenwerkendeCatalogiResourceService $samenwerkende_catalogi_resource) {
    $this->samenwerkendeCatalogiResource = $samenwerkende_catalogi_resource;
  }

  /**
   * @param string $enity_type_id
   *
   * @return array
   */
  public function build(string $enity_type_id) {
    $build = [];

    $build['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Add to Samenwerkende Catalogi'),
    ];

    $build['data'] = [
      '#type' => 'fieldset',
      '#tree' => TRUE,
    ];

    $build['data']['tokens'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => [$enity_type_id],
      '#global_types' => TRUE,
      '#show_nested' => FALSE,
    ];

    $build['data']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
    ];

    $build['data']['authority'] = [
      '#type' => 'select',
      '#title' => $this->t('Authority'),
      '#options' => $this->samenwerkendeCatalogiResource->getOptionsBySamenwerkendeCatalogiName('samenwerkende_catalogi_authority'),
    ];

    $build['data']['spatial'] = [
      '#type' => 'select',
      '#title' => $this->t('Spatial'),
      '#options' => $this->samenwerkendeCatalogiResource->getOptionsBySamenwerkendeCatalogiName('samenwerkende_catalogi_spatial'),
    ];

    $build['data']['audience'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Audience'),
      '#options' => [
        'particulier' => $this->t('Consumer'),
        'ondernemer' => $this->t('Entrepreneur'),
      ],
      '#multiple' => TRUE,
    ];

    $build['data']['subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subjects'),
      '#description' => $this->t('The findability of the product, such as keywords or theme layouts. Separate by comma or use a token.'),
    ];

    $build['data']['abstract'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Abstract'),
      '#description' => $this->t('Short description of the product, for presentation in the search results list of buyers. A length of approximately 300 characters is recommended. Plain text or token.'),
    ];

    $build['data']['onlineAanvragen'] = [
      '#type' => 'radios',
      '#title' => $this->t('Apply online'),
      '#description' => $this->t('Indicates whether the product can be requested online, and if so whether DigiD is used for this. If not applicable, enter \'no\' here.'),
      '#options' => [
        'ja' => $this->t('Yes'),
        'nee' => $this->t('No'),
        'digid' => $this->t('DigiD'),
      ],
    ];

    $build['data']['aanvraagURL'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Request URL'),
      '#description' => $this->t('Indicates where the product can be requested online, for example an electronic form. Plain text or token.'),
    ];

    $build['data']['uniformeProductnaam'] = [
      '#type' => 'select',
      '#title' => $this->t('Uniform product name'),
      '#options' => $this->samenwerkendeCatalogiResource->getOptionsBySamenwerkendeCatalogiName('samenwerkende_catalogi_upl'),
      '#multiple' => TRUE,
    ];

    $build['data']['gerelateerdProduct'] = [
      '#type' => 'select',
      '#title' => $this->t('Uniform product name of related products'),
      '#options' => $this->samenwerkendeCatalogiResource->getOptionsBySamenwerkendeCatalogiName('samenwerkende_catalogi_upl'),
      '#multiple' => TRUE,
    ];

    $build['data']['productHTML'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Product HTML'),
      '#description' => $this->t('Contains a fragment of formatted XHTML. When filling this field, keep in mind that the XHTML is valid and should be able to be presented as part of any (government) website.')
    ];

    return $build;

  }



}
